import {
  Cell,
  CellGroup,
  Skeleton,
  SkeletonAvatar,
  SkeletonParagraph
} from 'vant';
import { defineComponent, onMounted, reactive, watch } from 'vue';
import styles from './index.module.less';

export default defineComponent({
  name: 'skeleton-modal',
  props: {
    show: {
      type: Boolean,
      default: false
    },
    showCount: {
      type: Array,
      default: () => [1, 2, 3, 4, 5]
    }
  },
  setup(props, { slots }) {
    const forms = reactive({
      loading: false
    });

    onMounted(() => {
      forms.loading = props.show;
    });

    watch(
      () => props.show,
      () => {
        forms.loading = props.show;
      }
    );
    return () => (
      <Skeleton loading={forms.loading} style="flex-wrap: wrap">
        {{
          template: () => (
            <div
              style={{
                height: `calc(100vh - var(--header-height))`,
                overflow: 'hidden',
                width: '100%'
              }}>
              {props.showCount.map(() => (
                <CellGroup inset class={styles.lessonCellGroup}>
                  <Cell center class={styles.timeCell}>
                    {{
                      title: () => <SkeletonParagraph rowWidth={'40%'} />,
                      value: () => <SkeletonParagraph rowWidth={'40%'} />
                    }}
                  </Cell>
                  <Cell center border={false} valueClass={styles.skeletonClass}>
                    {{
                      icon: () => <SkeletonAvatar class={styles.iconStudent} />,
                      title: () => (
                        <div class={styles.userInfo}>
                          <SkeletonParagraph
                            class={styles.name}
                            rowWidth={'40%'}
                          />
                          <SkeletonParagraph
                            class={styles.subject}
                            rowWidth={'50%'}
                          />
                        </div>
                      ),
                      value: () => (
                        <SkeletonParagraph
                          class={styles.people}
                          rowWidth={'40%'}
                        />
                      )
                    }}
                  </Cell>
                  <Cell center class={styles.musicCell}>
                    {{
                      title: () => (
                        <SkeletonParagraph
                          class={styles.musicInfo}
                          rowWidth={'40%'}
                          style={{ marginTop: '10px' }}
                        />
                      ),
                      label: () => (
                        <SkeletonParagraph
                          class={styles.rowGroup}
                          rowWidth={'80%'}
                        />
                      )
                    }}
                  </Cell>
                </CellGroup>
              ))}
            </div>
          ),
          default: () => slots.default && slots.default()
        }}
      </Skeleton>
    );
  }
});
